@@ -195,7 +195,7 @@ class ListenerV3:
                 yield f"{Path(item.source).resolve() if item.source is not None else ''};{item.longname}"
                 return
 
-            yield f"{Path(item.source if item.source is not None else '').resolve()};{item.longname};{item.lineno}"
+            yield f"{Path(item.source).resolve() if item.source is not None else ''};{item.longname};{item.lineno}"
 
         if self._event_sended:
             return
