@@ -13,6 +13,9 @@ URI = str
 ProgressToken = Union[str, int]
 
 
+LSPAny = Any
+
+
 class ErrorCodes:
     PARSE_ERROR = -32700
     INVALID_REQUEST = -32600
@@ -981,6 +984,22 @@ class ExecuteCommandOptions(WorkDoneProgressOptions, _ExecuteCommandOptions):
     pass
 
 
+@dataclass(repr=False)
+class ExecuteCommandRegistrationOptions(ExecuteCommandOptions):
+    pass
+
+
+@dataclass(repr=False)
+class _ExecuteCommandParams(Model):
+    command: str
+    arguments: Optional[List[LSPAny]] = None
+
+
+@dataclass(repr=False)
+class ExecuteCommandParams(WorkDoneProgressParams, _ExecuteCommandParams):
+    pass
+
+
 @dataclass(repr=False)
 class SemanticTokensLegend(Model):
     token_types: List[str]
@@ -2368,3 +2387,16 @@ class CodeAction:
     edit: Optional[WorkspaceEdit] = None
     command: Optional[Command] = None
     data: Any = None
+
+
+@dataclass(repr=False)
+class ApplyWorkspaceEditParams(Model):
+    edit: WorkspaceEdit
+    label: Optional[str] = None
+
+
+@dataclass(repr=False)
+class ApplyWorkspaceEditResult(Model):
+    applied: bool
+    failure_reason: Optional[str] = None
+    failed_change: Optional[int] = None
