@@ -45,10 +45,11 @@ class RobotConfig(ConfigBase):
         return None
 
 
-@config_section("robotcode.syntax")
+@config_section("robotcode.completion")
 @dataclass
-class SyntaxConfig(ConfigBase):
-    section_style: Optional[str] = None
+class CompletionConfig(ConfigBase):
+    filter_default_language: bool = True
+    header_style: Optional[str] = None
 
 
 @config_section("robotcode.robocop")
@@ -76,8 +77,8 @@ class WorkspaceConfig(ConfigBase):
 @dataclass
 class AnalysisConfig(ConfigBase):
     diagnostic_mode: DiagnosticsMode = DiagnosticsMode.OPENFILESONLY
-    progress_mode: AnalysisProgressMode = AnalysisProgressMode.SIMPLE
-    max_project_file_count: int = 1000
+    progress_mode: AnalysisProgressMode = AnalysisProgressMode.OFF
+    max_project_file_count: int = 5000
     references_code_lens: bool = False
     find_unused_references: bool = False
 
@@ -94,7 +95,7 @@ class DocumentationServerConfig(ConfigBase):
 class RobotCodeConfig(ConfigBase):
     language_server: LanguageServerConfig = field(default_factory=LanguageServerConfig)
     robot: RobotConfig = field(default_factory=RobotConfig)
-    syntax: SyntaxConfig = field(default_factory=SyntaxConfig)
+    syntax: CompletionConfig = field(default_factory=CompletionConfig)
     workspace: WorkspaceConfig = field(default_factory=WorkspaceConfig)
     analysis: AnalysisConfig = field(default_factory=AnalysisConfig)
     documentation_server: DocumentationServerConfig = field(default_factory=DocumentationServerConfig)
