@@ -1,8 +1,7 @@
+import threading
 from collections import defaultdict
 from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, TypeVar, cast
 
-from .async_tools import Lock
-
 _T = TypeVar("_T")
 
 
@@ -16,7 +15,7 @@ class CacheEntry:
     def __init__(self) -> None:
         self.data: Any = None
         self.has_data: bool = False
-        self.lock: Lock = Lock()
+        self.lock = threading.RLock()
 
 
 class AsyncSimpleLRUCache:
@@ -27,29 +26,28 @@ class AsyncSimpleLRUCache:
         self._order: Optional[List[Tuple[Any, ...]]] = None
         if self.max_items:
             self._order = []
-        self.lock: Lock = Lock()
+        self._lock = threading.RLock()
 
     async def has(self, *args: Any, **kwargs: Any) -> bool:
         key = self._make_key(*args, **kwargs)
-        async with self.lock:
-            if key in self._cache:
-                return self._cache[key].has_data
+
+        if key in self._cache:
+            return self._cache[key].has_data
 
         return False
 
     async def get(self, func: Callable[..., Awaitable[_T]], *args: Any, **kwargs: Any) -> _T:
         key = self._make_key(*args, **kwargs)
 
-        # async with self.lock:
         entry = self._cache[key]
 
-        async with entry.lock:
+        with entry.lock:
             if not entry.has_data:
                 entry.data = await func(*args, **kwargs)
                 entry.has_data = True
 
                 if self._order is not None and self.max_items is not None:
-                    async with self.lock:
+                    with self._lock:
                         self._order.insert(0, key)
 
                         if len(self._order) > self.max_items:
@@ -62,7 +60,7 @@ class AsyncSimpleLRUCache:
         return (tuple(_freeze(v) for v in args), hash(frozenset({k: _freeze(v) for k, v in kwargs.items()})))
 
     async def clear(self) -> None:
-        async with self.lock:
+        with self._lock:
             self._cache.clear()
             if self._order is not None:
                 self._order.clear()
